# Manually maintained - do not edit by roxygen2

importFrom(stats, aggregate, cor, lm, median, na.omit, qf, sd, setNames, predict)
importFrom(utils, head, str)
importFrom(graphics, legend, lines)

export(sca)
export(sce)
export(print)
export(predict)
export(importance)
export(evaluate)
export(summary)
export(rfe_sce)
export(plot_rfe)

# S3 Methods
S3method(print, sce)
S3method(summary, sce)
S3method(predict, sce)
S3method(importance, sce)
S3method(evaluate, sce)
S3method(print, sca)
S3method(summary, sca)
S3method(predict, sca)
S3method(importance, sca)
S3method(evaluate, sca)
